@@ -50,13 +50,13 @@ class RealBridge(Bridge):
     def initialize(self):
         self.simulator = dict()
 
-    @register.bridge_params(driver_launch_file=None, launch_args=[])
-    def add_object(self, agnostic_params, bridge_params, node_params, state_params):
+    @register.bridge_config(driver_launch_file=None, launch_args=[])
+    def add_object(self, config, bridge_config, node_params, state_params):
         # add object to simulator (we have a ref to the simulator with self.simulator)
-        rospy.loginfo(f'Adding object "{agnostic_params["name"]}" of type "{agnostic_params["entity_id"]}" to the simulator.')
+        rospy.loginfo(f'Adding object "{config["name"]}" of type "{config["entity_id"]}" to the simulator.')
 
         # Extract relevant agnostic_params
-        obj_name = agnostic_params["name"]
+        obj_name = config["name"]
 
         # Create new env, and add to simulator
         self.simulator[obj_name] = dict(state=None, input=None)
