@@ -6,7 +6,7 @@ import rospy
 # IMPORT ROS
 from std_msgs.msg import UInt64, Bool
 from sensor_msgs.msg import Image
-from cv_bridge import CvBridge
+import cv_bridge
 
 # IMPORT EAGERX
 import eagerx.core.register as register
@@ -43,7 +43,7 @@ class CameraRender(EngineNode):
         spec.config.camera_idx = camera_idx
 
     def initialize(self, shape, camera_idx):
-        self.cv_bridge = CvBridge()
+        self.cv_bridge = cv_bridge.CvBridge()
         self.cam = None
         self.width, self.height = shape
         self.camera_idx = camera_idx
